# NOMAD-CAMELS driver for Keithley 2400

Driver of the Keithley 2400 source measure unit written for the measurement software [NOMAD-CAMELS](https://fau-lap.github.io/NOMAD-CAMELS/).

## Features
Currently supported are basic voltage and current setting and reading.
## Documentation

For more information and documentation visit the NOMAD-CAMELS [documentation](https://fau-lap.github.io/NOMAD-CAMELS/doc/instruments/instruments.html).